pub struct AbstractTicket {Show 22 fields
pub id: Rc<TicketId>,
pub summary: String,
pub description: Option<String>,
pub doc_type: String,
pub doc_text: String,
pub docs_contact: DocsContact,
pub status: String,
pub resolution: Option<String>,
pub is_open: bool,
pub priority: String,
pub url: String,
pub assignee: Option<String>,
pub components: Vec<String>,
pub product: String,
pub labels: Option<Vec<String>>,
pub flags: Option<Vec<String>>,
pub target_releases: Vec<String>,
pub subsystems: Result<Vec<String>, String>,
pub groups: Option<Vec<String>>,
pub public: bool,
pub doc_text_status: DocTextStatus,
pub references: Option<Vec<String>>,
}Expand description
An abstract ticket representation that generalizes over Bugzilla, Jira, and any other issue trackers.
Fields
id: Rc<TicketId>summary: Stringdescription: Option<String>doc_type: Stringdoc_text: Stringdocs_contact: DocsContactstatus: Stringresolution: Option<String>is_open: boolpriority: Stringurl: Stringassignee: Option<String>components: Vec<String>product: Stringlabels: Option<Vec<String>>flags: Option<Vec<String>>target_releases: Vec<String>subsystems: Result<Vec<String>, String>groups: Option<Vec<String>>public: booldoc_text_status: DocTextStatusreferences: Option<Vec<String>>Implementations
Sourceimpl AbstractTicket
impl AbstractTicket
Sourcepub fn release_note(
&self,
variant: DocumentVariant,
with_priv_footnote: bool,
) -> String
pub fn release_note( &self, variant: DocumentVariant, with_priv_footnote: bool, ) -> String
Compose a release note from an abstract ticket.
Sourcepub fn signature(&self, with_priv_footnote: bool) -> String
pub fn signature(&self, with_priv_footnote: bool) -> String
Prepare the link or the non-clickable signature that marks the ticket belonging to this release note.
For example, link:https://...bugzilla...12345[BZ#12345].